package com.bonus.material.lease.service;

import java.util.List;
import com.bonus.material.lease.domain.LeaseApplyDetails;

/**
 * 领料任务详细Service接口
 * 
 * @author xsheng
 * @date 2024-10-16
 */
public interface ILeaseApplyDetailsService {
    /**
     * 查询领料任务详细
     * 
     * @param id 领料任务详细主键
     * @return 领料任务详细
     */
    public LeaseApplyDetails selectLeaseApplyDetailsById(Long id);

    /**
     * 查询领料任务详细列表
     * 
     * @param leaseApplyDetails 领料任务详细
     * @return 领料任务详细集合
     */
    public List<LeaseApplyDetails> selectLeaseApplyDetailsList(LeaseApplyDetails leaseApplyDetails);

    /**
     * 新增领料任务详细
     * 
     * @param leaseApplyDetails 领料任务详细
     * @return 结果
     */
    public int insertLeaseApplyDetails(LeaseApplyDetails leaseApplyDetails);

    /**
     * 修改领料任务详细
     * 
     * @param leaseApplyDetails 领料任务详细
     * @return 结果
     */
    public int updateLeaseApplyDetails(LeaseApplyDetails leaseApplyDetails);

    /**
     * 批量删除领料任务详细
     * 
     * @param ids 需要删除的领料任务详细主键集合
     * @return 结果
     */
    public int deleteLeaseApplyDetailsByIds(Long[] ids);

    /**
     * 删除领料任务详细信息
     * 
     * @param id 领料任务详细主键
     * @return 结果
     */
    public int deleteLeaseApplyDetailsById(Long id);
}
