//package com.bonus.material.lease.controller;
//
//import java.util.List;
//import javax.servlet.http.HttpServletResponse;
//import com.bonus.common.log.enums.OperaType;
//import com.bonus.material.common.annotation.PreventRepeatSubmit;
//import io.swagger.annotations.Api;
//import io.swagger.annotations.ApiOperation;
//import org.springframework.beans.factory.annotation.Autowired;
//import org.springframework.web.bind.annotation.GetMapping;
//import org.springframework.web.bind.annotation.PostMapping;
//import org.springframework.web.bind.annotation.PutMapping;
//import org.springframework.web.bind.annotation.DeleteMapping;
//import org.springframework.web.bind.annotation.PathVariable;
//import org.springframework.web.bind.annotation.RequestBody;
//import org.springframework.web.bind.annotation.RequestMapping;
//import org.springframework.web.bind.annotation.RestController;
//import com.bonus.common.log.annotation.SysLog;
//import com.bonus.common.security.annotation.RequiresPermissions;
//import com.bonus.material.lease.domain.LeaseApplyDetails;
//import com.bonus.material.lease.service.ILeaseApplyDetailsService;
//import com.bonus.common.core.web.controller.BaseController;
//import com.bonus.common.core.web.domain.AjaxResult;
//import com.bonus.common.core.utils.poi.ExcelUtil;
//import com.bonus.common.core.web.page.TableDataInfo;
//
///**
// * 领料任务详细Controller
// *
// * @author xsheng
// * @date 2024-10-16
// */
//@Api(tags = "领料任务详细接口")
//@RestController
//@RequestMapping("/lease_apply_details")
//public class LeaseApplyDetailsController extends BaseController {
//    @Autowired
//    private ILeaseApplyDetailsService leaseApplyDetailsService;
//
//    /**
//     * 查询领料任务详细列表
//     */
//    @ApiOperation(value = "查询领料任务详细列表")
//    @RequiresPermissions("lease:details:list")
//    @GetMapping("/list")
//    public TableDataInfo list(LeaseApplyDetails leaseApplyDetails) {
//        startPage();
//        List<LeaseApplyDetails> list = leaseApplyDetailsService.selectLeaseApplyDetailsList(leaseApplyDetails);
//        return getDataTable(list);
//    }
//
//    /**
//     * 导出领料任务详细列表
//     */
//    @ApiOperation(value = "导出领料任务详细列表")
//    @PreventRepeatSubmit
//    @RequiresPermissions("lease:details:export")
//    @SysLog(title = "领料任务详细", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出领料任务详细")
//    @PostMapping("/export")
//    public void export(HttpServletResponse response, LeaseApplyDetails leaseApplyDetails) {
//        List<LeaseApplyDetails> list = leaseApplyDetailsService.selectLeaseApplyDetailsList(leaseApplyDetails);
//        ExcelUtil<LeaseApplyDetails> util = new ExcelUtil<LeaseApplyDetails>(LeaseApplyDetails.class);
//        util.exportExcel(response, list, "领料任务详细数据");
//    }
//
//    /**
//     * 获取领料任务详细详细信息
//     */
//    @ApiOperation(value = "获取领料任务详细详细信息")
//    @RequiresPermissions("lease:details:query")
//    @GetMapping(value = "/{id}")
//    public AjaxResult getInfo(@PathVariable("id") Long id) {
//        return success(leaseApplyDetailsService.selectLeaseApplyDetailsById(id));
//    }
//
//    /**
//     * 新增领料任务详细
//     */
//    @ApiOperation(value = "新增领料任务详细")
//    @PreventRepeatSubmit
//    @RequiresPermissions("lease:details:add")
//    @SysLog(title = "领料任务详细", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增领料任务详细")
//    @PostMapping
//    public AjaxResult add(@RequestBody LeaseApplyDetails leaseApplyDetails) {
//        try {
//            return toAjax(leaseApplyDetailsService.insertLeaseApplyDetails(leaseApplyDetails));
//        } catch (Exception e) {
//            return error("系统错误, " + e.getMessage());
//        }
//    }
//
//    /**
//     * 修改领料任务详细
//     */
//    @ApiOperation(value = "修改领料任务详细")
//    @PreventRepeatSubmit
//    @RequiresPermissions("lease:details:edit")
//    @SysLog(title = "领料任务详细", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改领料任务详细")
//    @PutMapping
//    public AjaxResult edit(@RequestBody LeaseApplyDetails leaseApplyDetails) {
//        try {
//            return toAjax(leaseApplyDetailsService.updateLeaseApplyDetails(leaseApplyDetails));
//        } catch (Exception e) {
//            return error("系统错误, " + e.getMessage());
//        }
//    }
//
//    /**
//     * 删除领料任务详细
//     */
//    @ApiOperation(value = "删除领料任务详细")
//    @PreventRepeatSubmit
//    @RequiresPermissions("lease:details:remove")
//    @SysLog(title = "领料任务详细", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除领料任务详细")
//	@DeleteMapping("/{ids}")
//    public AjaxResult remove(@PathVariable Long[] ids) {
//        return toAjax(leaseApplyDetailsService.deleteLeaseApplyDetailsByIds(ids));
//    }
//}
